local f1 = {}
local sec = "FontEngraving"
local inst = 0
	
_G.post = require 'mcFPost'

local function LeadingZeros(num, digits)
	--send in text and number of leading zeros
	--output string with leading zeros
	local lz = cbLeadZero:GetValue()
	if not lz then
		digits = 0
	end
	txt = string.format("%0" .. tostring(digits) .. "d", num)
	return txt
end

local function StrVarReplace(str)
	--Replace variables in string with values
	local tblVars = {
		[1] = "SN",
		[2] = "DATE",
		[3] = "TIME"
	}
	local tblVals = {
		["SN"] = LeadingZeros(txtSN:GetValue(), txtNumDigits:GetValue()),
		["DATE"] = os.date("%x"),
		["TIME"] = os.date("%X")
	}

	for _,v in ipairs(tblVars) do
		rplc = tostring(tblVals[v])
		if (v == "SN") and (cbLeadZero:GetValue()) then
			digits = txtNumDigits:GetValue()
			rplc = string.format("%0"..digits.."d", rplc)
		end
		var = "<" .. tostring(v) .. ">"
		str = str:gsub(var, rplc)
	end
    return str
end

local function GetStringGcode(festr, xstart, ystart)
		post.ClearSettings(xstart, ystart); 
	
		local strcode = ""
		local strl = festr:len()
		local i = 0;
		for i=1,strl,1 do
			local character = string.sub(festr, i, i)
			local ascii = string.byte(festr, i)
			func = tostring(character)
			if (font[func] == nil) then
				func = "ascii" .. tostring(ascii)
				if(font[func] == nil) then
					func = "ascii32"
				end
			end
			local lettercode = font[func]()
			if (func ~= "ascii32") then
				strcode = strcode .. lettercode .. "\n"	
			end
		end
		return strcode
end

local function GenGcode(input)

	local MachDirectory = mc.mcCntlGetMachDir(inst)
	local Profile = mc.mcProfileGetName(inst)
	local ScriptPath = MachDirectory .. "\\Modules\\AddOns\\FontEngraving\\?.lua;"

	local fontpath = mc.mcProfileGetString(inst, sec, "FONT", MachDirectory .. "\\Modules\\AddOns\\FontEngraving\\Fonts\\ScriptFont.lua")
	local path, file, ext = string.match(fontpath, "(.-)([^\\/]-%.?)([^%.\\/]*)$")
	local file = string.match(file, "[^%.]*")
	local ScriptPath = path .. "?." .. ext

	-- look for this path in the existing package.path.
	local spos = string.find(package.path, ScriptPath)
	if (spos == nil) then -- The path is not there, append it.
		package.path = package.path .. ";" .. ScriptPath
	end

	font = require (file)
	setmetatable(font,{__index = post})

	
	--Gcode string
	local gcode = ""
	--Check if input is a table or string. if it is a string add it to the txt table at index 0
	local txt = {}
	if (input == "string") then
		txt[1] = input
	else
		txt = input
	end
	local numlines = #txt
	local index = 1
	local gc = {}
	local ll = {}
	local align = rbAlignment:GetSelection()
	local xpos = tonumber(txtXPos:GetValue())
	local ypos = tonumber(txtYPos:GetValue())
	--y pos of first line and increment value
	local yinc = post.height * 1.25
	local halflines = numlines / 2
	if (halflines < 1) then
		ypos = ypos - (post.height / 2)
	else
		ypos = ypos + (yinc * (halflines - 1)) + (post.height * .125)
	end
	
	for _,r in ipairs(txt) do
		--gencode for each line
		gc[index] = GetStringGcode(r)
		ll[index] = post.letterStartX - (.25 * post.height)
		--set xpos
		local xpos2 = xpos
		if (align == 1) then
			xpos2 = xpos - ll[index]/2
		elseif (align == 2) then
			xpos2 = xpos - ll[index]
		end
		gc[index] = GetStringGcode(r, xpos2, ypos)
		gcode = gcode .. gc[index]
		--increment ypos
		ypos = ypos - yinc
		--increment line count
		index = index + 1
	end

	--var for character function
	local func = ""
	--gcode header
	gcode = post.ProgStart() .. gcode
	--gcode footer
	gcode = gcode .. post.ProgEnd()
	return gcode, ll
end

local function AssembleLines()
	local lcount = txtEngrave:GetNumberOfLines()
	local txt = {}
	local sn = txtSN:GetValue()
	local digits = txtNumDigits:GetValue()
	sn = LeadingZeros(sn, digits)
	for i = 0, (lcount - 1) do
		j = i + 1
		txt[j] = txtEngrave:GetLineText(i)
		txt[j] = StrVarReplace(txt[j])
		if (j == 1) then
			if (snPos == -1) then
				local spaces = spacePrefix:GetValue()
				if (tonumber(spaces) > 0) then
					for i = 1, tonumber(spaces) do
						sn = sn .. " "
					end
				end
				txt[j] = sn .. txt[j]
			elseif (snPos == 1) then
				local spaces = spaceSuffix:GetValue()
				if (tonumber(spaces) > 0) then
					for i = 1, tonumber(spaces) do
						sn = " " .. sn
					end
				end
				txt[j] = txt[j] .. sn
			end
		end
	end
	return txt
end

local function LoadParams(retonly)
	local zpos = mc.mcProfileGetString(inst, sec, "ZPOS", "0.0000")
	local depth = mc.mcProfileGetString(inst, sec, "DEPTH", "0.0080")
	local rapidh = mc.mcProfileGetString(inst, sec, "RAPIDHEIGHT", "0.250")
	local feedh = mc.mcProfileGetString(inst, sec, "FEEDHEIGHT", "0.0000")
	local plungef = mc.mcProfileGetString(inst, sec, "PLUNGEFEED", "30")
	local cutf = mc.mcProfileGetString(inst, sec, "CUTFEED", "30")
	local rpm = mc.mcProfileGetString(inst, sec, "RPM", "10000")
	local font = mc.mcProfileGetString(inst, sec, "FONT", "C:\\Mach4Hobby\\Modules\\AddOns\\FontEngraving\\Fonts\\StraightFont.lua")
	
	if not retonly then
		txtZPosition:SetValue(zpos)
		txtZDepth:SetValue(depth)
		txtRapidHeight:SetValue(rapidh)
		txtFeedHeight:SetValue(feedh)
		txtPlungeFeed:SetValue(plungef)
		txtCutFeed:SetValue(cutf)
		txtRPM:SetValue(rpm)
		fileFont:SetPath(font)
	end
	
	return zpos, depth, rapidh, feedh, plungef, cutf, rpm, font
end

local function SetVals()
	post.ClearSettings()
	local height = txtHeight:GetValue()
	local xpos = txtXPos:GetValue()
	local ypos = txtYPos:GetValue()
	post.setHeight(tonumber(height))
	post.setXStart(tonumber(xpos))
	post.setYStart(tonumber(ypos))
	
	local zpos, depth, rapidh, feedh, plungef, cutf, rpm = LoadParams(true)
	post.setRapidHeight(zpos + rapidh)
	post.setFeedHeight(zpos + feedh)
	post.setDepth(zpos - depth)
	post.setFeedPlung(plungef)
	post.setFeedCut(cutf)
	post.setRPM(rpm)
	
	return true
end

local function Update()
	local txt = AssembleLines()
	SetVals()
	local gcode, ll = GenGcode(txt)
	local length = 0
	for _,l in ipairs (ll) do
		if (l > length) then
			length = l
		end
	end
	txtWidth:SetValue(string.format("%.4f", length))
end

local function LoadFEPanel()
	local snPos = mc.mcProfileGetString(inst, sec, "SNPOS", "0")
	if (snPos == "-1") then
		rbSNPre:SetValue(true)
	elseif (snPos == "1") then
		rbSNSuf:SetValue(true)
	else
		rbSNNone:SetValue(true)
	end

	local spacepre = mc.mcProfileGetString(inst, sec, "SPACEPREFIX", "0")
	local spacesuf = mc.mcProfileGetString(inst, sec, "SPACESUFFIX", "0")
	local text = mc.mcProfileGetString(inst, sec, "TEXT", "Serial number <SN>\nDate <DATE> at <TIME>")
	local sn = mc.mcProfileGetString(inst, sec, "SN", "1")
	local autosn = mc.mcProfileGetString(inst, sec, "AUTOSN", "true")
	local leadzero = mc.mcProfileGetString(inst, sec, "LEADZERO", "true")
	local seqinc = mc.mcProfileGetString(inst, sec, "SEQINC", "1")
	local numdigits = mc.mcProfileGetString(inst, sec, "NUMDIGITS", "3")
	local xpos = mc.mcProfileGetString(inst, sec, "XPOS", "0")
	local ypos = mc.mcProfileGetString(inst, sec, "YPOS", "0")
	local alignment = mc.mcProfileGetString(inst, sec, "ALIGNMENT", "0")
	local height = mc.mcProfileGetString(inst, sec, "HEIGHT", "1")
	
	spacePrefix:SetValue(spacepre)
	spaceSuffix:SetValue(spacesuf)
	txtEngrave:SetValue(text)
	txtSN:SetValue(sn)
	
	if (autosn == "true") then
		cbAutoSN:SetValue(true)
	end
	if (leadzero == "true") then
		cbLeadZero:SetValue(true)
	end
	
	txtSeqInc:SetValue(seqinc)
	txtNumDigits:SetValue(numdigits)
	txtXPos:SetValue(xpos)
	txtYPos:SetValue(ypos)
	txtHeight:SetValue(height)
	rbAlignment:SetSelection(tonumber(alignment))
	Update()
end

local function IncrementSN()
	local autosn = cbAutoSN:GetValue()
	if autosn then
		local cursn = txtSN:GetValue()
		local sninc = txtSeqInc:GetValue()
		local nextsn = tonumber(cursn) + tonumber(sninc)
		txtSN:SetValue(tostring(nextsn))
		rc = mc.mcProfileWriteString(inst, sec, "SN", tostring(nextsn))
	end		
end

local function SaveFEPanel()
	local rc = -1
	
	local spacepre = spacePrefix:GetValue()
	local spacesuf = spaceSuffix:GetValue()
	local text = txtEngrave:GetValue()
	local sn = txtSN:GetValue()
	local autosn = cbAutoSN:GetValue()
	local leadzero = cbLeadZero:GetValue()
	local seqinc = txtSeqInc:GetValue()
	local numdigits = txtNumDigits:GetValue()
	local xpos = txtXPos:GetValue()
	local ypos = txtYPos:GetValue()
	local alignment = rbAlignment:GetSelection()
	local height = txtHeight:GetValue()
	
	rc = mc.mcProfileWriteString(inst, sec, "SNPOS", tostring(snPos))
	rc = mc.mcProfileWriteString(inst, sec, "SPACEPREFIX", tostring(spacepre))
	rc = mc.mcProfileWriteString(inst, sec, "SPACESUFFIX", tostring(spacesuf))
	rc = mc.mcProfileWriteString(inst, sec, "TEXT", tostring(text))
	rc = mc.mcProfileWriteString(inst, sec, "SN", tostring(sn))
	rc = mc.mcProfileWriteString(inst, sec, "AUTOSN", tostring(autosn))
	rc = mc.mcProfileWriteString(inst, sec, "LEADZERO", tostring(leadzero))
	rc = mc.mcProfileWriteString(inst, sec, "SEQINC", tostring(seqinc))
	rc = mc.mcProfileWriteString(inst, sec, "NUMDIGITS", tostring(numdigits))
	rc = mc.mcProfileWriteString(inst, sec, "XPOS", tostring(xpos))
	rc = mc.mcProfileWriteString(inst, sec, "YPOS", tostring(ypos))
	rc = mc.mcProfileWriteString(inst, sec, "ALIGNMENT", tostring(alignment))
	rc = mc.mcProfileWriteString(inst, sec, "HEIGHT", tostring(height))
	
	mc.mcCntlSetLastError(inst, "FE settings saved")
end

local function SaveParams()
	local zpos = txtZPosition:GetValue()
	local depth = txtZDepth:GetValue()
	local rapidh = txtRapidHeight:GetValue()
	local feedh = txtFeedHeight:GetValue()
	local plungef = txtPlungeFeed:GetValue()
	local cutf = txtCutFeed:GetValue()
	local rpm = txtRPM:GetValue()
	local font = fileFont:GetPath()
	
	mc.mcProfileWriteString(inst, sec, "ZPOS", zpos)
	mc.mcProfileWriteString(inst, sec, "DEPTH", depth)
	mc.mcProfileWriteString(inst, sec, "RAPIDHEIGHT", rapidh)
	mc.mcProfileWriteString(inst, sec, "FEEDHEIGHT", feedh)
	mc.mcProfileWriteString(inst, sec, "PLUNGEFEED", plungef)
	mc.mcProfileWriteString(inst, sec, "CUTFEED", cutf)
	mc.mcProfileWriteString(inst, sec, "RPM", rpm)
	mc.mcProfileWriteString(inst, sec, "FONT", font)
	
	mc.mcCntlSetLastError(inst, "FE cut parameters saved")
end

local function CreateFont()
    scale = 1;
	xshift = 0;
	yshift = 0;
	ascii = 33

	-- Vars to show mode and position
	linecnt = 1
	xcur = 0;
	xval = 0;
	xvallast = 0;
	xmax = -9999;
	xmin = 9999;
	xfirst = 0;
	xcuract = 0;
	xlast = 0;
	xstart = 0;
	ystart = 0;
	ycur = 0;
	icur = 0;
	jcur = 0;
	zdn = true;
	Zmove = false;
	movemode = -1;

	header = ""
	header = header .. "-----------------------------------------------------------------------------\n"
	header = header .. "-- Name:        Straight Font Module\n"
	header = header .. "-- Author:      Font Creator Script\n"
	header = header .. "-- Created:     " .. os.date("%x") .. "\n"
	header = header .. "-- Copyright:   (c) 2015 Newfangled Solutions. All rights reserved.\n"
	header = header .. "-- License:    \n"
	header = header .. "-----------------------------------------------------------------------------\n"
	header = header .. "local mcStraightFont = {}\n"
	header = header .. "local inst = mc.mcGetInstance()\n"
	header = header .. "local MachDirectory = mc.mcCntlGetMachDir(inst)\n"
	header = header .. "local Profile = mc.mcProfileGetName(inst)\n"
	header = header .. "local ScriptPath = MachDirectory .. '/Modules/AddOns/FontEngraving/?.lua;'\n"
	header = header .. "local spos = string.find(package.path, ScriptPath)\n"
	header = header .. "if (spos == nil) then \n"
	header = header .. "	package.path = package.path .. ';' .. ScriptPath\n"
	header = header .. "end\n"
	header = header .. "local f = require 'mcFPost'\n"
	header = header .. "setmetatable(mcStraightFont, {__index = f})\n"
	header = header .. "_ENV = mcStraightFont\n\n"
	header = header .. "ascii32 = function ()\n"
	header = header .. "return ( AddWidth(.75) );\n"
	header = header .. "end\n\n"
	

local spos = string.find(package.path, ScriptPath)
if (spos == nil) then 
	package.path = package.path .. ";" .. ScriptPath
end
	
	--header = header .. string.format("ascii%.0f = function ()\n", ascii)

	local function RemoveComment(str)
		local rvel = str;
		rvel = string.gsub(tostring(str), '%b()', '');
	return (rvel)
	end

	local function GetNumber(str)
		local val = '';
		local i = 0;
		for i=1, str:len(),1 do
			local c = string.byte(str, i)
			if ((c >= 48 and c <= 57) or c== 46 or c== 45) then
				val = val .. string.char(c);
			else
				return(tonumber(val))
			end
		end
		return(tonumber(val))
	end

	local function Convertline(gline);
		gline = RemoveComment(gline)
		gline = gline:upper();
		move = false;
		Zmove = false;
		local length = string.len(gline);
		local i = 1;
		local c = '';
		for i=1, length,1 do
			c = string.sub(gline, i, i);
			if (_G[c] ~= nil) then
				i = _G[c](gline, i);
			end
		end
		local retval = '';
		if(Zmove == true) then
			if (zdn == true)then
				retval = 'ZDn()\n'
			else
				retval = 'ZUp()\n'
			end
		else
			if(movemode == 0 or movemode == 1) then
				retval = string.format('G%i(%.5f,%.5f)\n', movemode, xcur, ycur);
			elseif(movemode == 2 or movemode == 3) then 
				retval = string.format('G%i(%.5f,%.5f,%.5f,%.5f)\n', movemode, xcur, ycur, icur, jcur);
			end
		end
		linecnt = linecnt + 1
		return (retval)
	end

	local function G(gline, i)
		i= i+1;
		local str = string.sub(gline, i, gline:len())
		local mode = GetNumber(str);
		if(tonumber(mode) >= 0 and tonumber(mode) <= 3) then
			movemode = mode;
		end
		return (i)
	end

	local function X(gline, i)
		i= i+1;
		local str = string.sub(gline, i, gline:len())
		xcur = GetNumber(str);
		xcuract = xcur
		xcur = (xcur * scale ) + xshift;
		xcur = xcur - xmin
		if (xcur > xlast) then
			xlast = xcur
		end
		return i, xcuract
	end

	local function Y(gline, i)
		i= i+1;
		local str = string.sub(gline, i, gline:len())
		ycur = GetNumber(str);
		ycur = (ycur * scale ) + yshift;
		return (i)
	end

	local function I(gline, i)
		i=i+1
		local str = string.sub(gline, i, gline:len())
		icur = GetNumber(str)
		icur = (icur * scale)
		return(i)
	end

	local function J(gline, i)
		i=i+1
		local str = string.sub(gline, i, gline:len())
		jcur = GetNumber(str)
		jcur = (jcur * scale)
		return(i)
	end

	local function Z(gline, i)
		i= i+1;
		local str = string.sub(gline, i, gline:len())
		local Zval = GetNumber(str);
		if(Zval > 0 and zdn == true) then 
			Zmove = true
			zdn = false
		elseif(zdn == false) then 
			Zmove = true
			zdn = true

		end
		return (i)
	end

	local function ConvertFile(Gcodefile, FontFile)
		FontFile:write(header)
		local gline = Gcodefile:read('*line') --Get the first line
		local index = 1
		local gstr = {}
		local startposx = 1
		local startposy = 1
		while gline~=nil do --check to see if we have a valid line
			--index lines into a table
			gstr[index] = RemoveComment(gline)
			gstr[index] = gstr[index]:upper()
			local str = gstr[index]
			local xchar = string.find(str, "X")
			local ychar = string.find(str, "Y")
			--find x vals to find the min, max positions and the end of the character
			if (xchar ~= nil) then
				local xstr = string.sub(str, (xchar + 1), str:len())
				xval = GetNumber(xstr)
				if (startposx == 1) then
					xstart = (xval * scale) + xshift
					startposx = 0
				end
				if (xval < xmin) then
					xmin = xval
				end
				if (xval > xmax) and ((xval - xvallast) < 1)then
					xmax = xval
				end
			end
			if (startposy == 1) and (ychar ~= nil) then
				local ystr = string.sub(str, (ychar + 1), str:len())
				yval = GetNumber(ystr)
				ystart = (yval * scale) + yshift
				startposy = 0
			end
			if ((xval - xvallast) > 2) then
				--write character start
				local newsec = string.format("-- %s\n", string.char(ascii))
				newsec = newsec .. string.format("ascii%.0f = function()\n", ascii)
				newsec = newsec .. "ZUp()\n"
				newsec = newsec .. string.format('G%i(%.5f,%.5f)\n', 0, (xstart - xmin), ystart);
				FontFile:write(newsec)
				--write indexed lines to file
				for i = 1, (index-1), 1 do
					local s = Convertline(gstr[i]);
					FontFile:write(s);
				end
				--end section
				local endsec = string.format("return (AddWidth(%.3f))\n", (xmax - xmin))
				endsec = endsec .. "end\n\n"
				FontFile:write(endsec)
				--reset values for next round
				xmin = 9999
				xmax = -9999
				xlast = 0
				index = 1
				startposx = 1
				startposy = 1
				ascii = ascii + 1
			else
				index = index + 1
			end
			
			xvallast = xval
			gline = Gcodefile:read('*line')
		end
		local footer = "\nreturn mcStraightFont\n";
		FontFile:write(footer);
	end

	--Funcs {}
	--Funcs['G'] = G

	-- create the wxFrame window
	mainframe = wx.wxFrame( wx.NULL,          -- no parent
							wx.wxID_ANY,          -- whatever for wxWindow ID
							"DummyFrame", -- frame caption
							wx.wxDefaultPosition, -- place the frame in default position
							wx.wxDefaultSize,     -- default frame size
							wx.wxDEFAULT_FRAME_STYLE ) -- use default frame styles

		-- create a panel in the frame
	panel = wx.wxPanel(mainframe, wx.wxID_ANY)--We are not going to show it but we need to have this to use the File dialog

	local file = wx.wxFileDialog(panel, "Select Font File To Convert", "", "", "NC files (*.nc)|*.nc|Text files (*.txt)|*.txt|Tap files (*.tap)|*.tap", 
								 wx.wxFD_OPEN,wx.wxDefaultPosition,wx.wxDefaultSize, "File Dialog" );
	if(file:ShowModal() == wx.wxID_OK)then
		local path = file:GetPath();
		local dir;
		local filename;
		dir,filename = wx.wxFileName.SplitPath(path)
		local FontCode = dir .. '\\' .. filename ..'.lua';
		local Gcodefile = io.open(path, 'r');
		local FontFile = io.open(FontCode, 'w+');
		ConvertFile(Gcodefile, FontFile);
		FontFile:flush();
		Gcodefile:close();
		FontFile:close();
		wx.wxMessageBox('Input : ' .. path .. '\nOutput : ' ..  FontCode , 'File Converted', wx.wxICON_ERROR)
	end 
end

function f1.Panel()

	inst = mc.mcGetInstance()
	local MachDirectory = mc.mcCntlGetMachDir(inst)
	local Profile = mc.mcProfileGetName(inst)
	local ScriptPath = MachDirectory .. "\\Modules\\AddOns\\FontEngraving\\?.lua;"
	
	-- look for this path in the existing package.path.
	local spos = string.find(package.path, ScriptPath)
	if (spos == nil) then -- The path is not there, append it.
		package.path = package.path .. ";" .. ScriptPath
	end

	package.loaded.mcFPost = nil
	post = require "mcFPost"

	if(mcLuaPanelParent == nil)then
		-- create the wxFrame window
		mainframe = wx.wxFrame( wx.NULL,          -- no parent
							wx.wxID_ANY,          -- whatever for wxWindow ID
							"Mach4 Font Engraving", -- frame caption
							wx.wxDefaultPosition, -- place the frame in default position
							wx.wxSize(800,500),     -- default frame size
							wx.wxDEFAULT_FRAME_STYLE ) -- use default frame styles

		fSizer = wx.wxBoxSizer( wx.wxVERTICAL )

		-- create a panel in the frame
		FEPanel = wx.wxPanel(mainframe, wx.wxID_ANY)	
		fSizer:Add( FEPanel, 1, wx.wxEXPAND  + wx. wxALL, 5 )
	else	
		FEPanel = mcLuaPanelParent
		FEPanel :SetBackgroundColour( wx.wxSystemSettings.GetColour( wx.wxSYS_COLOUR_WINDOW ) )
		local window = FEPanel:GetParent()
		local wsize = window:GetSize()
		FEPanel:SetSize(wsize)
	end

	mainSizer = wx.wxBoxSizer( wx.wxVERTICAL )
	
	nbMain = wxaui.wxAuiNotebook( FEPanel, wx.wxID_ANY, wx.wxDefaultPosition, wx.wxDefaultSize, wxaui.wxAUI_NB_DEFAULT_STYLE )
	tabEngrave = wx.wxPanel( nbMain, wx.wxID_ANY, wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxTAB_TRAVERSAL )
		engraveSizer = wx.wxBoxSizer( wx.wxVERTICAL )
		
		txtSizer = wx.wxFlexGridSizer( 0, 7, 0, 0 )
		txtSizer:SetFlexibleDirection( wx.wxBOTH )
		txtSizer:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		txtSizer:Add( 50, 0, 1, wx.wxEXPAND, 5 )
		
		lbl1 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Prefix SN", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl1:Wrap( -1 )
		txtSizer:Add( lbl1, 0, wx.wxALIGN_BOTTOM + wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALL, 5 )
		
		lbl2 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Prefix Spaces", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl2:Wrap( -1 )
		txtSizer:Add( lbl2, 0, wx.wxALIGN_BOTTOM + wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALL, 5 )
		
		lbl3 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Text To Engrave", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl3:Wrap( -1 )
		txtSizer:Add( lbl3, 0, wx.wxALIGN_BOTTOM + wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALL, 5 )
		
		lbl4 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Suffix Spaces", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl4:Wrap( -1 )
		txtSizer:Add( lbl4, 0, wx.wxALIGN_BOTTOM + wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALL, 5 )
		
		lbl5 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Suffix SN", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl5:Wrap( -1 )
		txtSizer:Add( lbl5, 0, wx.wxALIGN_BOTTOM + wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALL, 5 )
		
		lbl6 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "No SN", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl6:Wrap( -1 )
		txtSizer:Add( lbl6, 0, wx.wxALIGN_BOTTOM + wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALL, 5 )
		
		txtSizer:Add( 50, 0, 1, wx.wxEXPAND, 5 )
		
		rbSNPre = wx.wxRadioButton( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxRB_GROUP )
		txtSizer:Add( rbSNPre, 0, wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALIGN_TOP + wx.wxALL, 5 )
		
		spacePrefix = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxSize( 25,-1 ), wx.wxTE_CENTRE, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		spacePrefix:SetMaxLength( 2 ) 
		txtSizer:Add( spacePrefix, 0, wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALIGN_TOP + wx.wxALL, 5 )
		
		txtEngrave = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxSize( 400,-1 ), wx.wxTE_CENTRE + wx.wxTE_MULTILINE )
		txtSizer:Add( txtEngrave, 0, wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALIGN_TOP + wx.wxALL, 5 )
		
		spaceSuffix = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxSize( 25,-1 ), wx.wxTE_CENTRE, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		spaceSuffix:SetMaxLength( 2 ) 
		txtSizer:Add( spaceSuffix, 0, wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALIGN_TOP + wx.wxALL, 5 )
		
		rbSNSuf = wx.wxRadioButton( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		txtSizer:Add( rbSNSuf, 0, wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALIGN_TOP + wx.wxALL, 5 )
		
		rbSNNone = wx.wxRadioButton( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		txtSizer:Add( rbSNNone, 0, wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALIGN_TOP + wx.wxALL, 5 )
		
		txtSizer:Add( 0, 0, 1, wx.wxEXPAND, 5 )
	    
		txtSizer:Add( 0, 0, 1, wx.wxEXPAND, 5 )
		
		txtSizer:Add( 0, 0, 1, wx.wxEXPAND, 5 )
		
		lblstaticText23 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "To add a serial number, date or time use the following in your text string.\nBe sure to include the < and > tags. <SN> <DATE> <TIME>", wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxALIGN_CENTRE )
		lblstaticText23:Wrap( -1 )
		txtSizer:Add( lblstaticText23, 0, wx.wxALIGN_CENTER_HORIZONTAL + wx.wxALL, 5 )
		
		engraveSizer:Add( txtSizer, 1, wx.wxALIGN_CENTER_HORIZONTAL, 5 )
		
		snSizer = wx.wxFlexGridSizer( 0, 5, 0, 0 )
		snSizer:SetFlexibleDirection( wx.wxBOTH )
		snSizer:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		lbl7 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Serial Number", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl7:Wrap( -1 )
		snSizer:Add( lbl7, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		txtSN = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxTE_CENTRE, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		snSizer:Add( txtSN, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		snSizer2 = wx.wxFlexGridSizer( 0, 3, 0, 0 )
		snSizer2:SetFlexibleDirection( wx.wxBOTH )
		snSizer2:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		cbAutoSN = wx.wxCheckBox( tabEngrave, wx.wxID_ANY, "Auto Sequential SN", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		snSizer2:Add( cbAutoSN, 0, wx.wxALIGN_CENTER_VERTICAL + wx.wxALIGN_LEFT + wx.wxALL, 5 )
		
		lbl8 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Sequential Increment", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl8:Wrap( -1 )
		snSizer2:Add( lbl8, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		txtSeqInc = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxSize( 50,-1 ), wx.wxTE_CENTRE + wx.wxWANTS_CHARS + wx.wxTE_PROCESS_ENTER, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		snSizer2:Add( txtSeqInc, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		cbLeadZero = wx.wxCheckBox( tabEngrave, wx.wxID_ANY, "Leading Zeros", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		snSizer2:Add( cbLeadZero, 0, wx.wxALIGN_CENTER_VERTICAL + wx.wxALIGN_LEFT + wx.wxALL, 5 )
		
		lbl81 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Number of Digits", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl81:Wrap( -1 )
		snSizer2:Add( lbl81, 0, wx.wxALL, 5 )
		
		txtNumDigits = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxSize( 50,-1 ), wx.wxTE_CENTRE + wx.wxWANTS_CHARS + wx.wxTE_PROCESS_ENTER, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		snSizer2:Add( txtNumDigits, 0, wx.wxALL, 5 )
		
		snSizer:Add( snSizer2, 1, wx.wxEXPAND, 5 )
		
		engraveSizer:Add( snSizer, 1, wx.wxALIGN_CENTER_HORIZONTAL, 5 )
		
		setSizer = wx.wxFlexGridSizer( 0, 3, 0, 0 )
		setSizer:SetFlexibleDirection( wx.wxBOTH )
		setSizer:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		posSizer = wx.wxFlexGridSizer( 0, 2, 0, 0 )
		posSizer:SetFlexibleDirection( wx.wxBOTH )
		posSizer:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		lbl9 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "X Start", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl9:Wrap( -1 )
		posSizer:Add( lbl9, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		txtXPos = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxTE_CENTRE + wx.wxWANTS_CHARS + wx.wxTE_PROCESS_ENTER, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		posSizer:Add( txtXPos, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		lbl10 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Y Start", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl10:Wrap( -1 )
		posSizer:Add( lbl10, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		txtYPos = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxTE_CENTRE + wx.wxWANTS_CHARS + wx.wxTE_PROCESS_ENTER, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		posSizer:Add( txtYPos, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		setSizer:Add( posSizer, 1, wx.wxALIGN_CENTER, 5 )
		
		rbAlignmentChoices = { "Left-Center", "Center-Center", "Right-Center" }
		rbAlignment = wx.wxRadioBox( tabEngrave, wx.wxID_ANY, "Alignment", wx.wxDefaultPosition, wx.wxDefaultSize, rbAlignmentChoices, 3, wx.wxRA_SPECIFY_COLS )
		rbAlignment:SetSelection( 0 )
		setSizer:Add( rbAlignment, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		posSizer1 = wx.wxFlexGridSizer( 0, 2, 0, 0 )
		posSizer1:SetFlexibleDirection( wx.wxBOTH )
		posSizer1:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		lbl11 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Height", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl11:Wrap( -1 )
		posSizer1:Add( lbl11, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		txtHeight = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxTE_CENTRE, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		posSizer1:Add( txtHeight, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		lbl12 = wx.wxStaticText( tabEngrave, wx.wxID_ANY, "Width", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl12:Wrap( -1 )
		posSizer1:Add( lbl12, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		txtWidth = wx.wxTextCtrl( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxTE_CENTRE, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		txtWidth:SetBackgroundColour( wx.wxSystemSettings.GetColour( wx.wxSYS_COLOUR_SCROLLBAR ) )
		
		posSizer1:Add( txtWidth, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		
		setSizer:Add( posSizer1, 1, wx.wxEXPAND, 5 )
		
		
		engraveSizer:Add( setSizer, 1, wx.wxALIGN_CENTER, 5 )
		
		fgSizer9 = wx.wxFlexGridSizer( 0, 3, 0, 0 )
		fgSizer9:SetFlexibleDirection( wx.wxBOTH )
		fgSizer9:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		btnSizer1 = wx.wxBoxSizer( wx.wxVERTICAL )
		
		btnSave = wx.wxButton( tabEngrave, wx.wxID_ANY, "Save and Load", wx.wxDefaultPosition, wx.wxSize( 100,50 ), 0 )
		btnSizer1:Add( btnSave, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		btnLoad = wx.wxButton( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxSize( 100,50 ), 0 )
		btnSizer1:Add( btnLoad, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		
		fgSizer9:Add( btnSizer1, 1, wx.wxEXPAND, 5 )
		
		pnlPreview = wx.wxPanel( tabEngrave, wx.wxID_ANY, wx.wxDefaultPosition, wx.wxSize( 500,75 ), wx.wxSTATIC_BORDER )
		fgSizer9:Add( pnlPreview, 1, wx.wxALL + wx.wxEXPAND, 5 )
		
		btnSizer2 = wx.wxBoxSizer( wx.wxVERTICAL )
		
		btnCutParams = wx.wxButton( tabEngrave, wx.wxID_ANY, "Cut\nParameters", wx.wxDefaultPosition, wx.wxSize( 100,50 ), 0 )
		btnSizer2:Add( btnCutParams, 0, wx.wxALL, 5 )
		
		btnPlcHolder = wx.wxButton( tabEngrave, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxSize( 100,50 ), 0 )
		btnSizer2:Add( btnPlcHolder, 0, wx.wxALL, 5 )
		
		
		fgSizer9:Add( btnSizer2, 1, wx.wxEXPAND, 5 )
		
		
		engraveSizer:Add( fgSizer9, 1, wx.wxALIGN_CENTER, 5 )
		
		
		tabEngrave:SetSizer( engraveSizer )
		tabEngrave:Layout()
		engraveSizer:Fit( tabEngrave )
		nbMain:AddPage( tabEngrave, "Font Engraving", False, wx.wxNullBitmap )
		
	tabCutParams = wx.wxPanel( nbMain, wx.wxID_ANY, wx.wxDefaultPosition, wx.wxDefaultSize, wx.wxTAB_TRAVERSAL )
		frmSizer = wx.wxBoxSizer( wx.wxHORIZONTAL )
		
		frmSizer3 = wx.wxBoxSizer( wx.wxVERTICAL )
		
		lbl109 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Font Engraving Cut Parameters", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl109:Wrap( -1 )
		lbl109:SetFont( wx.wxFont( wx.wxNORMAL_FONT:GetPointSize(), 70, 90, 90, true, "" ) )
		frmSizer3:Add( lbl109, 0, wx.wxALL + wx.wxALIGN_CENTER, 5 )
		
		frmSizer2 = wx.wxFlexGridSizer( 0, 2, 0, 0 )
		frmSizer2:SetFlexibleDirection( wx.wxBOTH )
		frmSizer2:SetNonFlexibleGrowMode( wx.wxFLEX_GROWMODE_SPECIFIED )
		
		lbl101 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Z Position", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl101:Wrap( -1 )
		frmSizer2:Add( lbl101, 0, wx.wxALL, 5 )
		
		txtZPosition = wx.wxTextCtrl( tabCutParams, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		frmSizer2:Add( txtZPosition, 0, wx.wxALL, 5 )
		
		lbl102 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Z Depth", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl102:Wrap( -1 )
		frmSizer2:Add( lbl102, 0, wx.wxALL, 5 )
		
		txtZDepth = wx.wxTextCtrl( tabCutParams, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		frmSizer2:Add( txtZDepth, 0, wx.wxALL, 5 )
		
		lbl103 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Rapid Height", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl103:Wrap( -1 )
		frmSizer2:Add( lbl103, 0, wx.wxALL, 5 )
		
		txtRapidHeight = wx.wxTextCtrl( tabCutParams, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		frmSizer2:Add( txtRapidHeight, 0, wx.wxALL, 5 )
		
		lbl104 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Feed Height", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl104:Wrap( -1 )
		frmSizer2:Add( lbl104, 0, wx.wxALL, 5 )
		
		txtFeedHeight = wx.wxTextCtrl( tabCutParams, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		frmSizer2:Add( txtFeedHeight, 0, wx.wxALL, 5 )
		
		lbl105 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Plunge Feed", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl105:Wrap( -1 )
		frmSizer2:Add( lbl105, 0, wx.wxALL, 5 )
		
		txtPlungeFeed = wx.wxTextCtrl( tabCutParams, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		frmSizer2:Add( txtPlungeFeed, 0, wx.wxALL, 5 )
		
		lbl106 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Cut Feed", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl106:Wrap( -1 )
		frmSizer2:Add( lbl106, 0, wx.wxALL, 5 )
		
		txtCutFeed = wx.wxTextCtrl( tabCutParams, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		frmSizer2:Add( txtCutFeed, 0, wx.wxALL, 5 )
		
		lbl107 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "RPM", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl107:Wrap( -1 )
		frmSizer2:Add( lbl107, 0, wx.wxALL, 5 )
		
		txtRPM = wx.wxTextCtrl( tabCutParams, wx.wxID_ANY, "", wx.wxDefaultPosition, wx.wxDefaultSize, 0, wx.wxTextValidator(wx.wxFILTER_NUMERIC) )
		frmSizer2:Add( txtRPM, 0, wx.wxALL, 5 )
		
		
		frmSizer3:Add( frmSizer2, 1, wx.wxALL + wx.wxALIGN_CENTER, 5 )
		
		lbl108 = wx.wxStaticText( tabCutParams, wx.wxID_ANY, "Select Font File", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		lbl108:Wrap( -1 )
		lbl108:SetFont( wx.wxFont( wx.wxNORMAL_FONT:GetPointSize(), 70, 90, 90, true, "" ) )
		frmSizer3:Add( lbl108, 0, wx.wxALL + wx.wxALIGN_CENTER, 5 )
		
		fileFont = wx.wxFilePickerCtrl( tabCutParams, wx.wxID_ANY, "", "Select a file", "*.*", wx.wxDefaultPosition, wx.wxSize( 400,-1 ), wx.wxFLP_DEFAULT_STYLE+wx.wxTAB_TRAVERSAL )
		frmSizer3:Add( fileFont, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		frmSizer4 = wx.wxBoxSizer( wx.wxHORIZONTAL )
		
		btnSaveCutParams = wx.wxButton( tabCutParams, wx.wxID_ANY, "Save", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		frmSizer4:Add( btnSaveCutParams, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		btnCancel = wx.wxButton( tabCutParams, wx.wxID_ANY, "Cancel", wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		frmSizer4:Add( btnCancel, 0, wx.wxALIGN_CENTER + wx.wxALL, 5 )
		
		
		frmSizer3:Add( frmSizer4, 1, wx.wxALIGN_CENTER, 5 )
		
		
		frmSizer:Add( frmSizer3, 1, wx.wxALL + wx.wxALIGN_CENTER, 5 )
		
		bmpCutParams = wx.wxStaticBitmap( tabCutParams, wx.wxID_ANY, wx.wxBitmap( f1.tblXPM["CutParams"] ), wx.wxDefaultPosition, wx.wxDefaultSize, 0 )
		frmSizer:Add( bmpCutParams, 0, wx.wxALL + wx.wxALIGN_CENTER, 5 )
		
		
		tabCutParams:SetSizer( frmSizer )
		tabCutParams:Layout()
		frmSizer:Fit( tabCutParams )
		nbMain:AddPage( tabCutParams, "Cut Parameters", False, wx.wxNullBitmap )
	
	mainSizer:Add( nbMain, 1, wx.wxEXPAND  + wx. wxALL, 5 )
	nbMain:SetTabCtrlHeight(0)
	
	FEPanel:SetSizer( mainSizer )
	FEPanel:Layout()
	
	if(mcLuaPanelParent == nil)then
        FEPanel:Fit()
        --mainframe:Fit()
        mainframe:Show(true)
    else
		window = FEPanel:GetParent()
		window:Connect(wx.wxID_ANY, wx.wxEVT_SIZE,
		function(event)
			local wsize = event:GetSize()
			FEPanel:SetSize(wsize)
			FEPanel:FitInside()
		end)
	end
	--Load saved values
	LoadFEPanel()
	LoadParams()
	
	
	-- Connect Events

	FEPanel:Connect( wx.wxEVT_SIZE, function(event)
		--implements --size
		tabCutParams:Refresh()
		tabEngrave:Refresh()
	event:Skip()
	end )

	rbSNPre:Connect( wx.wxEVT_COMMAND_RADIOBUTTON_SELECTED, function(event)
	--implements rbSNPreOnRadioButton
		snPos = -1
		Update()
	end )

	spacePrefix:Connect( wx.wxEVT_COMMAND_TEXT_UPDATED, function(event)
	--implements spacePrefixOnText
		Update()
	end )

	txtEngrave:Connect( wx.wxEVT_COMMAND_TEXT_UPDATED, function(event)
	--implements txtEngraveOnText
		Update()
	end )

	spaceSuffix:Connect( wx.wxEVT_COMMAND_TEXT_UPDATED, function(event)
	--implements spaceSufixOnText
		Update()
	end )

	rbSNSuf:Connect( wx.wxEVT_COMMAND_RADIOBUTTON_SELECTED, function(event)
	--implements rbSNSufOnRadioButton
		snPos = 1
		Update()
	end )

	rbSNNone:Connect( wx.wxEVT_COMMAND_RADIOBUTTON_SELECTED, function(event)
	--implements rbSNNoneOnRadioButton
		snPos = 0
		Update()
	end )

	txtSN:Connect( wx.wxEVT_COMMAND_TEXT_UPDATED, function(event)
	--implements txtSNOnText
		Update()
	end )

	cbAutoSN:Connect( wx.wxEVT_COMMAND_CHECKBOX_CLICKED, function(event)
	--implements cbAutoSNOnCheckBox
		local checked = cbAutoSN:GetValue()
		if checked then
			mc.mcCntlSetLastError(inst, "Auto sequential serial number")
		else
			mc.mcCntlSetLastError(inst, "Manual serial number")
		end
	end )

	cbLeadZero:Connect( wx.wxEVT_COMMAND_CHECKBOX_CLICKED, function(event)
	--implements cbLeadZeroOnCheckBox
		local checked = cbLeadZero:GetValue()
		if checked then
			mc.mcCntlSetLastError(inst, "Apply leading zeros")
		else
			mc.mcCntlSetLastError(inst, "No leading zeros")
		end
		Update()
	end )

	txtSeqInc:Connect( wx.wxEVT_COMMAND_TEXT_ENTER, function(event)
	--implements txtSeqIncOnTextEnter
		SetVals()
		Update()
	end )

	txtNumDigits:Connect( wx.wxEVT_COMMAND_TEXT_ENTER, function(event)
	--implements txtNumDigitsOnTextEnter
		SetVals()
		Update()
	end )

	txtXPos:Connect( wx.wxEVT_COMMAND_TEXT_ENTER, function(event)
	--implements txtXPosOnTextEnter
		SetVals()
	end )

	txtYPos:Connect( wx.wxEVT_COMMAND_TEXT_ENTER, function(event)
	--implements txtYPosOnTextEnter
		SetVals()
	end )

	rbAlignment:Connect( wx.wxEVT_COMMAND_RADIOBOX_SELECTED, function(event)
	--implements rbAlignmentOnRadioBox
		local sel = rbAlignment:GetSelection()
		if (sel == 0) then
			mc.mcCntlSetLastError(inst, "Left align")
		elseif (sel == 1) then
			mc.mcCntlSetLastError(inst, "Center align")
		elseif (sel == 2) then
			mc.mcCntlSetLastError(inst, "Right align")
		end
		Update()
	end )

	txtHeight:Connect( wx.wxEVT_COMMAND_TEXT_UPDATED, function(event)
	--implements txtHeightOnText
		SetVals()
		Update()
	end )

	btnSave:Connect( wx.wxEVT_COMMAND_BUTTON_CLICKED, function(event)
	--implements btnSaveOnButtonClick
		SaveFEPanel()
		SaveParams()
		local txt = AssembleLines()
		SetVals()
		local gcode = GenGcode(txt)
		
		mc.mcCntlCloseGCodeFile(inst)
		--save new file
		local file = wx.wxFileDialog(tabEngrave, "Select Gcode File", "", "", "NC files (*.nc)|*.nc|Text files (*.txt)|*.txt|Tap files (*.tap)|*.tap", 
							  wx.wxFD_SAVE,wx.wxDefaultPosition,wx.wxDefaultSize, "Save Engraving GCode" );
		if (file:ShowModal() == wx.wxID_OK) then
			local gcodepath = file:GetPath()
			local gcodefile = io.open(gcodepath, "w")
			gcodefile:write(gcode)
			gcodefile:close()

			--load new gcode
			mc.mcCntlLoadGcodeFile(inst, gcodepath)
			mc.mcToolPathGenerate(inst)
		end
		
		IncrementSN()
	end )

	btnLoad:Connect( wx.wxEVT_COMMAND_BUTTON_CLICKED, function(event)
	--implements btnLoadOnButtonClick
		mc.mcCntlSetLastError(inst, "This button does nothing")
		--SaveFEPanel()
		--SaveParams()
		--local txt = AssembleLines()
		--SetVals()
		--local gcode = GenGcode(txt)
		--mc.mcCntlCloseGCodeFile(inst)
		--local rc = mc.mcCntlLoadGcodeString(inst, gcode)
		--mc.mcToolPathGenerate(inst)
		--
		--IncrementSN()
	end )

	btnCutParams:Connect( wx.wxEVT_COMMAND_BUTTON_CLICKED, function(event)
	--implements btnCutParamsOnButtonClick
		nbMain:SetSelection(1)
	end )

	btnPlcHolder:Connect( wx.wxEVT_COMMAND_BUTTON_CLICKED, function(event)
	--implements btnPlcHolderOnButtonClick
		mc.mcCntlSetLastError(inst, "This button does nothing")
	end )
	
	--Connect Events ( Cut parameters )
	
	btnSaveCutParams:Connect( wx.wxEVT_COMMAND_BUTTON_CLICKED, function(event)
	--implements btnSaveOnButtonClick
		SaveParams()
		nbMain:SetSelection(0)
	end )
	
	btnCancel:Connect( wx.wxEVT_COMMAND_BUTTON_CLICKED, function(event)
	--implements btnCancelOnButtonClick
		nbMain:SetSelection(0)
	end )
	
	fileFont:Connect( wx.wxEVT_COMMAND_FILEPICKER_CHANGED, function(event)
	--implements fileFontOnFileChanged
		local filename = fileFont:GetFileName()
		mc.mcCntlSetLastError(inst, "New font selected: " .. filename)
	end )
	
	lbl108:Connect( wx.wxEVT_RIGHT_DCLICK, function(event)
	--implements lbl108OnRightDClick
		CreateFont()
	end )
end


f1.tblXPM = {}
f1.tblXPM["CutParams"] = {
"470 417 597 2",
"  	c #FFFFFF",
". 	c #FBFBFC",
"+ 	c #BFC0C5",
"@ 	c #B3B5BA",
"# 	c #B3B4B9",
"$ 	c #B0B1B7",
"% 	c #B4B6BB",
"& 	c #B5B6BB",
"* 	c #ADAEB3",
"= 	c #AFB0B5",
"- 	c #B8B9BF",
"; 	c #C1C2C8",
"> 	c #C2C3C9",
", 	c #C4C5CB",
"' 	c #BBBDC3",
") 	c #BABBC1",
"! 	c #B9BBC1",
"~ 	c #BABCC2",
"{ 	c #BCBDC4",
"] 	c #BCBEC5",
"^ 	c #BDBFC6",
"/ 	c #BFC1C8",
"( 	c #CED0D7",
"_ 	c #CCCED5",
": 	c #D0D2D9",
"< 	c #CACCD3",
"[ 	c #EEEEF0",
"} 	c #F6F6F7",
"| 	c #6C6E7B",
"1 	c #525662",
"2 	c #51535F",
"3 	c #4A4D59",
"4 	c #535864",
"5 	c #51545F",
"6 	c #565863",
"7 	c #434651",
"8 	c #474955",
"9 	c #5B606C",
"0 	c #707380",
"a 	c #737683",
"b 	c #787A88",
"c 	c #646775",
"d 	c #616472",
"e 	c #606372",
"f 	c #626574",
"g 	c #656878",
"h 	c #666B7A",
"i 	c #686C7C",
"j 	c #6D7180",
"k 	c #8F93A3",
"l 	c #8B8E9F",
"m 	c #9397A7",
"n 	c #878A9B",
"o 	c #D8D9DD",
"p 	c #F7F7F8",
"q 	c #777985",
"r 	c #5F636E",
"s 	c #5E606B",
"t 	c #585B66",
"u 	c #606570",
"v 	c #5E616B",
"w 	c #63656F",
"x 	c #51545E",
"y 	c #555762",
"z 	c #686C77",
"A 	c #7B7E8A",
"B 	c #7E818D",
"C 	c #828591",
"D 	c #6D707D",
"E 	c #6C6F7D",
"F 	c #6E717F",
"G 	c #717482",
"H 	c #727684",
"I 	c #747786",
"J 	c #787C8A",
"K 	c #979BAA",
"L 	c #9497A6",
"M 	c #9B9FAE",
"N 	c #9093A3",
"O 	c #DBDCE0",
"P 	c #60636E",
"Q 	c #9094A3",
"R 	c #777A85",
"S 	c #60626E",
"T 	c #787B8A",
"U 	c #979AAA",
"V 	c #979AA9",
"W 	c #969AA9",
"X 	c #70737F",
"Y 	c #9B9FAD",
"Z 	c #686B77",
"` 	c #777C8A",
" .	c #9B9EAD",
"..	c #777B8A",
"+.	c #9A9EAD",
"@.	c #9397A6",
"#.	c #969AA8",
"$.	c #9094A4",
"%.	c #9194A4",
"&.	c #DCDCE0",
"*.	c #9699A8",
"=.	c #686B76",
"-.	c #9194A3",
";.	c #787A85",
">.	c #9599A8",
",.	c #9195A3",
"'.	c #787A86",
").	c #707482",
"!.	c #9195A4",
"~.	c #9B9EAE",
"{.	c #606470",
"].	c #52545E",
"^.	c #545762",
"/.	c #777B89",
"(.	c #686A76",
"_.	c #777A86",
":.	c #F7F8F8",
"<.	c #777B86",
"[.	c #787B86",
"}.	c #676A76",
"|.	c #636570",
"1.	c #5F616C",
"2.	c #676A75",
"3.	c #5E616C",
"4.	c #6F737F",
"5.	c #9599A7",
"6.	c #60636F",
"7.	c #9598A7",
"8.	c #F7F8F9",
"9.	c #787B87",
"0.	c #636670",
"a.	c #9498A7",
"b.	c #DCDDE0",
"c.	c #F8F8F9",
"d.	c #9195A5",
"e.	c #9498A6",
"f.	c #9295A5",
"g.	c #676975",
"h.	c #6F727F",
"i.	c #9598A8",
"j.	c #9A9FAD",
"k.	c #9296A5",
"l.	c #666975",
"m.	c #5F616B",
"n.	c #9296A4",
"o.	c #9699A9",
"p.	c #7E808D",
"q.	c #828491",
"r.	c #797B87",
"s.	c #DCDDE1",
"t.	c #666974",
"u.	c #818491",
"v.	c #6C707D",
"w.	c #979BA9",
"x.	c #9296A6",
"y.	c #60656F",
"z.	c #9396A6",
"A.	c #DDDDE1",
"B.	c #989BAA",
"C.	c #7C7E8A",
"D.	c #989BAB",
"E.	c #9497A7",
"F.	c #989CAB",
"G.	c #DDDEE1",
"H.	c #60646F",
"I.	c #585B65",
"J.	c #818490",
"K.	c #5F626B",
"L.	c #999DAB",
"M.	c #9BA0AE",
"N.	c #5E626B",
"O.	c #999CAC",
"P.	c #5E626C",
"Q.	c #5F626C",
"R.	c #999DAC",
"S.	c #9C9FAE",
"T.	c #7D818D",
"U.	c #9C9FAF",
"V.	c #9CA0AE",
"W.	c #656974",
"X.	c #777A89",
"Y.	c #9A9DAC",
"Z.	c #63666F",
"`.	c #9A9DAD",
" +	c #DDDEE2",
".+	c #797C87",
"++	c #61636F",
"@+	c #9398A6",
"#+	c #9398A7",
"$+	c #DEDEE2",
"%+	c #656874",
"&+	c #DEDFE2",
"*+	c #61646F",
"=+	c #DEDFE3",
"-+	c #DFDFE3",
";+	c #DFE0E3",
">+	c #60626C",
",+	c #60626D",
"'+	c #959AA8",
")+	c #959AA9",
"!+	c #DFE0E4",
"~+	c #767A89",
"{+	c #E0E0E4",
"]+	c #5D606B",
"^+	c #5D606A",
"/+	c #969AAA",
"(+	c #A0A4B4",
"_+	c #A2A5B5",
":+	c #E0E1E4",
"<+	c #656873",
"[+	c #6D707E",
"}+	c #717583",
"|+	c #757988",
"1+	c #747887",
"2+	c #878B99",
"3+	c #828592",
"4+	c #7A7D8B",
"5+	c #858897",
"6+	c #E0E1E5",
"7+	c #6F727E",
"8+	c #6D717E",
"9+	c #6D707F",
"0+	c #616571",
"a+	c #565964",
"b+	c #4D505A",
"c+	c #474A53",
"d+	c #444750",
"e+	c #41444D",
"f+	c #3E414A",
"g+	c #D3D4D7",
"h+	c #6E727F",
"i+	c #6F7380",
"j+	c #696C79",
"k+	c #585B67",
"l+	c #494C57",
"m+	c #454851",
"n+	c #464953",
"o+	c #474A54",
"p+	c #484B54",
"q+	c #454852",
"r+	c #E2E2E3",
"s+	c #717480",
"t+	c #5D5F6B",
"u+	c #4A4C56",
"v+	c #484A54",
"w+	c #494B55",
"x+	c #393C47",
"y+	c #8B8D93",
"z+	c #858894",
"A+	c #6B6E79",
"B+	c #4F515C",
"C+	c #464851",
"D+	c #464852",
"E+	c #454752",
"F+	c #DEDEE0",
"G+	c #757883",
"H+	c #4D4F59",
"I+	c #474953",
"J+	c #4A4D57",
"K+	c #3B3E49",
"L+	c #94959B",
"M+	c #7F828D",
"N+	c #737682",
"O+	c #4E515B",
"P+	c #4D505B",
"Q+	c #E9EAEB",
"R+	c #545761",
"S+	c #50535E",
"T+	c #50535D",
"U+	c #50525D",
"V+	c #51535E",
"W+	c #424450",
"X+	c #97989E",
"Y+	c #5F626D",
"Z+	c #4F525D",
"`+	c #535661",
" @	c #4F525E",
".@	c #555763",
"+@	c #EAEAEB",
"@@	c #5A5D68",
"#@	c #555864",
"$@	c #565864",
"%@	c #484B58",
"&@	c #96989F",
"*@	c #585A65",
"=@	c #595B68",
"-@	c #575A66",
";@	c #515460",
">@	c #D8D9DC",
",@	c #585A66",
"'@	c #5C5F6B",
")@	c #5B5E6A",
"!@	c #535663",
"~@	c #797B85",
"{@	c #FEFEFE",
"]@	c #5C606A",
"^@	c #62656F",
"/@	c #52545F",
"(@	c #5E616E",
"_@	c #5D616D",
":@	c #5D606D",
"<@	c #505361",
"[@	c #B0B1B8",
"}@	c #62646E",
"|@	c #555863",
"1@	c #616470",
"2@	c #606370",
"3@	c #E3E3E6",
"4@	c #61646E",
"5@	c #656875",
"6@	c #646774",
"7@	c #5D606E",
"8@	c #7D7F8A",
"9@	c #FCFCFC",
"0@	c #5C5F69",
"a@	c #666976",
"b@	c #6D6F7D",
"c@	c #6C6E7C",
"d@	c #6B6E7B",
"e@	c #616371",
"f@	c #9E9FA8",
"g@	c #5B5F69",
"h@	c #666973",
"i@	c #757784",
"j@	c #787A87",
"k@	c #777986",
"l@	c #777886",
"m@	c #787886",
"n@	c #6C6E7D",
"o@	c #C6C7CD",
"p@	c #595D66",
"q@	c #6F727C",
"r@	c #858694",
"s@	c #838492",
"t@	c #7E7F8D",
"u@	c #595C66",
"v@	c #757783",
"w@	c #8F91A0",
"x@	c #8D8F9D",
"y@	c #8B8D9C",
"z@	c #8E909E",
"A@	c #F0F0F2",
"B@	c #575B65",
"C@	c #80838F",
"D@	c #9295A4",
"E@	c #8F93A2",
"F@	c #9699A7",
"G@	c #F2F3F4",
"H@	c #585B64",
"I@	c #9396A5",
"J@	c #9397A5",
"K@	c #A0A4B0",
"L@	c #F9FAFA",
"M@	c #7F8390",
"N@	c #8D91A0",
"O@	c #9DA1AE",
"P@	c #F9F9FA",
"Q@	c #8D90A0",
"R@	c #9DA0AD",
"S@	c #626570",
"T@	c #F6F7F8",
"U@	c #727681",
"V@	c #575A64",
"W@	c #575A63",
"X@	c #808491",
"Y@	c #9B9EAB",
"Z@	c #FDFDFD",
"`@	c #90929A",
" #	c #454853",
".#	c #4C4E58",
"+#	c #4B4D57",
"@#	c #4B4E58",
"##	c #454751",
"$#	c #6C6F7C",
"%#	c #8B8E9E",
"&#	c #A7AAB6",
"*#	c #FDFEFC",
"=#	c #B2DE84",
"-#	c #A7D972",
";#	c #FAFDF8",
">#	c #FBFDF9",
",#	c #9ED564",
"'#	c #C8E7A7",
")#	c #D5ECBB",
"!#	c #96D257",
"~#	c #F6FBF0",
"{#	c #EAEAEC",
"]#	c #565762",
"^#	c #474954",
"/#	c #555862",
"(#	c #888B9B",
"_#	c #C6C8D0",
":#	c #92D050",
"<#	c #D9EEC2",
"[#	c #E5F3D5",
"}#	c #94D154",
"|#	c #E7F5D9",
"1#	c #F0F8E8",
"2#	c #99D35B",
"3#	c #A8A9AF",
"4#	c #434551",
"5#	c #848796",
"6#	c #8C8F9F",
"7#	c #E4E4E8",
"8#	c #656771",
"9#	c #494C55",
"0#	c #43454E",
"a#	c #727583",
"b#	c #9EA0AE",
"c#	c #FAFAFB",
"d#	c #B4DE86",
"e#	c #C3C4C8",
"f#	c #464854",
"g#	c #494B56",
"h#	c #494C56",
"i#	c #444650",
"j#	c #5B5E69",
"k#	c #898C9C",
"l#	c #B9BBC4",
"m#	c #C2E59E",
"n#	c #F6FBF1",
"o#	c #E4F3D4",
"p#	c #F2F9EA",
"q#	c #7A7B85",
"r#	c #42444F",
"s#	c #898D9C",
"t#	c #D9DADF",
"u#	c #DBDCDF",
"v#	c #4E505C",
"w#	c #7A7D8A",
"x#	c #8E91A1",
"y#	c #9799A8",
"z#	c #F5F5F7",
"A#	c #94959D",
"B#	c #40424E",
"C#	c #44464F",
"D#	c #8A8D9D",
"E#	c #ADAFBB",
"F#	c #EEEEEF",
"G#	c #5B5D68",
"H#	c #8D92A1",
"I#	c #CDCFD5",
"J#	c #AEB0B5",
"K#	c #484B55",
"L#	c #7F8290",
"M#	c #9498A8",
"N#	c #8F92A2",
"O#	c #9193A2",
"P#	c #EDEEF0",
"Q#	c #6D6F79",
"R#	c #43464F",
"S#	c #6A6D7A",
"T#	c #8B8F9F",
"U#	c #A2A5B1",
"V#	c #9CD460",
"W#	c #C8C9CD",
"X#	c #444752",
"Y#	c #888C9C",
"Z#	c #C3C5CD",
"`#	c #82838C",
" $	c #3D404B",
".$	c #858998",
"+$	c #8F94A3",
"@$	c #E3E4E8",
"#$	c #E7F4D9",
"$$	c #F3FAED",
"%$	c #DEDFE1",
"&$	c #4D4F5A",
"*$	c #40434C",
"=$	c #717481",
"-$	c #8C91A0",
";$	c #9C9DA4",
">$	c #373A45",
",$	c #5C5F6A",
"'$	c #B7B9C3",
")$	c #F1F1F2",
"!$	c #595B65",
"~$	c #D6D8DD",
"{$	c #B7B8BD",
"]$	c #383B45",
"^$	c #787C89",
"/$	c #9599A9",
"($	c #8E92A1",
"_$	c #F3F3F5",
":$	c #686A72",
"<$	c #5A5D6A",
"[$	c #898D9E",
"}$	c #ACAFBA",
"|$	c #CECED1",
"1$	c #494C58",
"2$	c #878C9D",
"3$	c #C9CBD2",
"4$	c #82838A",
"5$	c #6F7382",
"6$	c #EAEAED",
"7$	c #DFDFE0",
"8$	c #A5A8B5",
"9$	c #A2A4AC",
"0$	c #B4B7C0",
"a$	c #F1F2F3",
"b$	c #E6E7E9",
"c$	c #AEDC7C",
"d$	c #F9FCF5",
"e$	c #B8E08D",
"f$	c #F8F9FA",
"g$	c #D8D9E0",
"h$	c #9599AA",
"i$	c #9DA0B1",
"j$	c #9C9FB1",
"k$	c #9C9FB0",
"l$	c #9B9FB0",
"m$	c #9B9EB0",
"n$	c #999DAF",
"o$	c #9A9EAF",
"p$	c #EBECEF",
"q$	c #E7E8EC",
"r$	c #999DAE",
"s$	c #9B9EAF",
"t$	c #9CA0B1",
"u$	c #9DA1B2",
"v$	c #EEEEF1",
"w$	c #D4D5DC",
"x$	c #898DA0",
"y$	c #9195A8",
"z$	c #9094A8",
"A$	c #9094A6",
"B$	c #8F94A6",
"C$	c #8F93A6",
"D$	c #8F93A7",
"E$	c #888CA1",
"F$	c #AEB1C0",
"G$	c #A8ABB9",
"H$	c #8F93A5",
"I$	c #9094A7",
"J$	c #9095A8",
"K$	c #9296A9",
"L$	c #ECECEF",
"M$	c #D5D6DD",
"N$	c #8C90A3",
"O$	c #9498AA",
"P$	c #9397AA",
"Q$	c #9397A9",
"R$	c #9297A9",
"S$	c #8B8FA3",
"T$	c #DCDDE3",
"U$	c #D7D8DF",
"V$	c #8A8EA2",
"W$	c #9296A8",
"X$	c #9398AA",
"Y$	c #9599AB",
"Z$	c #EDEDF0",
"`$	c #8C91A4",
" %	c #FCFCFD",
".%	c #F8F8FA",
"+%	c #8D92A5",
"@%	c #898DA2",
"#%	c #CBCDD6",
"$%	c #C5C7D1",
"%%	c #898DA1",
"&%	c #9598AB",
"*%	c #F1F2F4",
"=%	c #9196A8",
"-%	c #BABDC8",
";%	c #B5B8C3",
">%	c #8A8EA1",
",%	c #9195A7",
"'%	c #8D91A4",
")%	c #E3E4E9",
"!%	c #9296A7",
"~%	c #AAADBB",
"{%	c #FDFDFE",
"]%	c #A6A9B8",
"^%	c #898EA1",
"/%	c #DFE0E6",
"(%	c #D8DAE0",
"_%	c #888CA0",
":%	c #9B9FAF",
"<%	c #9398A9",
"[%	c #9498A9",
"}%	c #9297A8",
"|%	c #D2D3DB",
"1%	c #85899D",
"2%	c #8C92A4",
"3%	c #8C90A4",
"4%	c #8B90A4",
"5%	c #8B90A3",
"6%	c #8B8FA4",
"7%	c #8C90A5",
"8%	c #8C92A5",
"9%	c #8E93A6",
"0%	c #E0E1E6",
"a%	c #B0B3C0",
"b%	c #AFB3C0",
"c%	c #AFB2C0",
"d%	c #AFB2BF",
"e%	c #B1B4C1",
"f%	c #F2F2F4",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        . + @ # $ % # & * = - ; > , ' ) ! ! ~ { ] ^ / ( _ : < [                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        } | 1 2 3 4 5 6 7 8 9 0 a b c d e e f g h i j k l m n o                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p q r s t u v w x y z A B C 0 D E E F G H I J K L M N O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p q P s t u v w x y z A B C 0 D E E F G H I J K L M N O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p q P s t u v w x y z A B C 0 D E E F G H I J K L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R S s t u v w x y z A B C 0 D E E F G H I J K L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R S s t u v w x y z A B C 0 D E E F G H I J K L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R S s t u v w x y z A B C 0 D E E F G H I T U L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R S s t u v w x y z A B C 0 D E E F G H I T V L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R S s t u v w x y z A B C 0 D E E F G H I T W L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R S s t u v w x y z A B C 0 D E E F G H I T W L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y z A B C 0 D E E F G H I T W L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y z A B C X D E E F G H I J W L M Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y z A B C X D E E F G H I J W L Y Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y z A B C X D E E F G H I J W L Y Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I J W L Y Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I J W L Y Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ` W L  .Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ..W L +.Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I T W @. .Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ..W L  .Q O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ..#.L  .$.O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ..#.L  .$.O                                                                                                                                                                                                                                                                                                                                                                                                                                                             ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ..W L  .%.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ..W @. .%.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y Z A B C X D E E F G H I ..*.@. .%.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y =.A B C X D E E F G H I ..*.@. .%.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y =.A B C X D E E F G H I ..*.@. .%.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p R P s t u v w x y =.A B C X D E E F G H I ..*.@. .-.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p ;.P s t u v w x y =.A B C 0 D E E F G H I ..*.L  .-.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p ;.P s t u v w x y =.A B C 0 D E E F G H I ..>.L  .-.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p ;.P v t u v w x y =.A B C 0 D E E F G H I ..>.L  .-.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p ;.P v t u v w x y =.A B C 0 D E E F G H I ..>.L  .-.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p ;.P v t u v w x y =.A B C 0 D E E F G H I ..>.L  .-.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p ;.P v t u v w x y =.A B C 0 D E E F G H I ..>.L  .,.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p ;.P v t u v w x y =.A B C 0 D E E F G H I ..>.L  .,.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t u v w x y =.A B C 0 D E E F ).H I ..>.L  .!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t u v w x y =.A B C 0 D E E F ).H I ..>.L ~.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t u v w x y =.A B C 0 D E E F ).H I ..>.L ~.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t {.v w x y =.A B C 0 D E E F ).H I ..>.@.~.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t {.v w x y =.A B C 0 D E E F ).H I ..>.@.~.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t {.v w x y =.A B C 0 D E E F ).H I ..>.@. .!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t {.v w x y =.A B C 0 D E E F ).H I ..>.@.Y !.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t {.v w ].^.=.A B C X D E E F ).H I /.>.@.Y !.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t {.v w ].^.=.A B C X D E E F ).H I /.>.@.Y !.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p '.P v t {.v w ].^.(.A B C X D E E F ).H I /.>.@.Y !.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p _.P v t {.v w ].^.(.A B C X D E E F ).H I /.>.L Y !.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p _.P v t {.v w ].^.(.A B C X D E E F ).H I /.>.L  .!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        p _.P v t {.v w ].^.(.A B C X D E E F ).H I /.>.L  .!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.<.P v t {.v w ].^.(.A B C X D E E F ).H I /.>.L  .!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P v t {.v w ].^.}.A B C X D E E F ).H I /.>.L  .!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P v t {.v w ].^.}.A B C X D E E F ).H I /.>.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P v t {.v |.].^.}.A B C X D E E F ).H I /.>.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P v t {.v |.].^.}.A B C X D E E F ).H I /.>.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P 1.t {.v |.].^.}.A B C X D E E F ).H I /.>.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P 1.t {.v |.].^.}.A B C X D E E F ).H I /.>.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P 1.t {.v |.].^.2.A B C X D E E F ).H I /.>.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.P 3.t {.v |.].^.2.A B C 4.D E E F ).H I /.5.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.6.3.t {.v |.].^.2.A B C 4.D E E F ).H I /.7.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        :.[.6.3.t {.v |.].^.2.A B C 4.D E E F ).H I /.7.L +.!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.L  .!.&.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.L  .!.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.L +.!.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.L +.d.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.L +.d.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.e.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.e. .f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a. .f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a. .f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a. .f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a. .f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.P 3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.P 3.t {.v 0.].^.2.A B C 4.D E E F ).H I /.a.a.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.P 3.t {.v 0.].^.g.A B C 4.D E E F ).H I /.a.7.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.g.A B C 4.D E E F ).H I /.a.7.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.P 3.t {.v 0.].^.g.A B C 4.D E E F ).H I /.a.7.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.P 3.t {.v 0.].^.g.A B C h.D E E F ).H I /.a.i.j.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.P 3.t {.v 0.].^.g.A B C h.D E E F ).H I /.a.i.j.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.P 3.t {.v 0.].^.g.A B C h.D E E F ).H I /.a.i.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.g.A B C h.D E E F ).H I /.a.>.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.g.A B C h.D E E F ).H I /.a.>.+.f.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.g.A B C h.D E E F ).H I /.a.>.j.k.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t {.v 0.].^.g.A B C h.D E E F ).H I /.a.>.Y k.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t u v 0.].^.l.A B C h.D E E F ).H I /.a.>.Y k.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.3.t u m.0.].^.l.A B C h.D E E F ).H I /.a.>.Y k.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.1.t u m.0.].^.l.A B C h.D E E F ).H I /.a.*.Y n.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.1.t u m.0.].^.l.A B C h.D E E F ).H I /.a.o.Y n.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.1.t u m.0.].^.l.A B C h.D E E F ).H I /.a.o.Y k.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.1.t u m.0.].^.l.A B C h.D E E F ).H I /.a.W j.k.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.9.6.1.t u m.0.].^.l.A p.q.h.D E E F ).H I /.a.W Y k.b.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.l.A p.q.h.D E E F ).H I /.a.W Y k.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A p.u.h.D E E F ).H I /.a.W Y k.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A B u.h.D v.E F ).H I /.a.W Y k.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A B u.h.D v.E F ).H I /.a.V M k.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A B u.h.D v.E F ).H I /.L w.M k.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A B u.h.D v.E F ).H I /.e.U M k.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A B u.h.D v.E F ).H I /.e.K Y k.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A B u.h.D v.E F ).H I /.a.K Y x.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t u m.0.].^.t.A B u.h.D v.E F ).H I /.a.K Y x.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t y.m.0.].^.t.A B u.h.D v.E F ).H I /.a.K M x.s.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t y.m.0.].^.t.A B u.h.D v.E F ).H I /.a.K M z.A.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t y.m.0.].^.t.A B u.h.D v.E F ).H I /.a.K M z.A.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t y.m.0.].^.t.A B u.h.D v.E F ).H I /.a.B.M z.A.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t y.m.0.].^.t.C.B u.h.D v.E F ).H I /.a.B.M z.A.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t y.m.0.].^.t.C.B u.h.D v.E F ).H I /.a.D.M z.A.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t y.m.0.].^.t.C.B u.h.D v.E F ).H I /.E.F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t H.m.0.].^.t.C.B u.h.D v.E F ).H I /.E.F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t H.m.0.].^.t.C.B u.h.D v.E F ).H I /.E.F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t H.m.0.].^.t.C.B u.h.D v.E F ).H I /.E.F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.t H.m.0.].^.t.C.B u.h.D v.E F ).H I /.E.F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.H.m.0.].^.t.C.B u.h.D v.E F ).H I /.L F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.{.m.0.].^.t.C.B u.h.D v.E F ).H I /.L F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.{.m.0.].^.t.C.B J.h.D v.E F ).H I /.L F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.{.m.0.].^.t.C.B J.h.D v.E F ).H I /.L F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.{.m.0.].^.t.C.B J.h.D v.E F ).H I /.L F.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.{.K.0.].^.t.C.B J.h.D v.E F ).H I /.@.L.M.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.{.N.0.].^.t.C.B J.h.D v.E F ).H I /.@.O.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.{.N.0.].^.t.C.B J.h.D v.E F ).H I /.@.O.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.1.I.H.P.0.].^.t.C.B J.h.D v.E F ).H I /.@.O.M @.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.P.0.].^.t.C.B J.h.D v.E F ).H I /.@.R.S.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.P.0.].^.t.C.T.J.h.D v.E F ).H I /.@.R.U.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.P.0.].^.t.C.T.J.h.D v.E F ).H I /.@.R.S.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.P.0.].^.t.A B J.h.D v.E F ).H I /.@.R.V.m G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.P.0.].^.t.A B J.h.D v.E F ).H I /.@.R.V.m G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.3.0.].^.t.A B J.h.D v.E F ).H I /.@.R.V.m G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.3.0.].^.t.A B J.h.D v.E F ).H I /.@.R.V.m G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.3.0.].^.W.A B J.h.D v.E F ).H I X.@.R.V.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.3.0.].^.W.A B J.h.D v.E F ).H I X.@.R.V.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.1.0.].^.W.A B J.h.D E E F ).H I X.@.R.V.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.1.0.].^.W.A B J.h.D E E F ).H I X.@.Y.S.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.1.Z.].^.W.A B J.h.D E E F ).H I X.@.Y.S.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.3.Z.].^.W.A B J.h.D E E F ).H I X.@.`.V.@.G.                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.6.Q.I.H.3.Z.].^.W.A B J.h.D E E F ).H I X.@.`.V.@. +                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+6.Q.I.{.v Z.].^.W.A B J.h.D E E F ).H I X.@.`.V.@. +                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+6.Q.I.{.v Z.].^.W.A B J.h.D E E F ).H I X.L +.V.@. +                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.++Q.I.{.v Z.].^.W.A B J.h.D E E F ).H I X.L +.V.@. +                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.++Q.I.{.v Z.].^.W.A B J.h.D E E F ).H I X.L +.S.@+ +                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.++Q.I.{.v Z.].^.W.A B J.h.D E E F ).H I X.L +.V.#+$+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.++Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.+.V.a.$+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.++Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.+.V.a.&+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.+.V.a.&+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.+.V.i.=+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c.r.*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.+.V.>.=+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@. .V.>.-+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@. .V.>.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@. .S.>.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@. .M >.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.M M >.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+Q.I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.M M.>.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+>+I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.M S.>.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+>+I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.M S.>.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+>+I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.M V.>.;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.{.v Z.].^.%+A B J.h.D E E F ).H I X.@.M V.'+;+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.{.s Z.].^.%+A B J.h.D E E F ).H I X.@.M M.)+!+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.{.s Z.].^.%+A B J.h.D E E F ).H I ~+@.M V.W !+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.s Z.].^.%+A B J.h.D E E F ).H I ~+@.M V.W {+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.]+Z.].^.%+A B J.h.D E E F ).H I ~+@.M S.W {+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.]+Z.].^.%+A B J.h.D v.E F ).H I ~+@.M S.W {+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.^+w ].^.%+A B J.h.D v.E F ).H I ~+@.M S.W {+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.^+w ].^.%+A B J.h.D v.E F ).H I ../+(+_++.:+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.^+w ].^.<+A B J.h.[+v.E F }+|+X.1+2+3+4+5+6+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.^+w ].^.<+A B J.7+8+v.9+G [+0+a+b+c+d+e+f+g+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.H.^+w ].^.<+A B J.7+h+i+j+k+l+m+m+n+o+p+q+c+r+                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        c..+*+,+I.y.^+w ].^.<+A B J.s+h+t+u+m+v+w+w+w+w+w+x+y+                                                                                                                                                                                                                                                                                                                                                                                                                                                              ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.y.^+w ].^.<+A B z+A+B+C+v+w+w+w+w+w+w+D+E+F+                                                                                                                                                                                                                                                                                                                                                                                                                                                              ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.y.^+w ].^.<+A u.G+H+I+u+u+u+u+u+u+u+J+K+L+                                                                                                                                                                                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.y.^+w ].^.<+M+N+O+J+b+b+b+b+b+b+b+b+l+P+Q+                                                                                                                                                                                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.y.^+w ].^.2.[.R+b+S+T+U+U+U+U+U+U+V+W+X+                                                                                                                                                                                                                                                                                                                                                                                                                                                                  ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.H.^+w ].^.t.Y+Z+`+`+`+`+`+`+`+`+`+ @.@+@                                                                                                                                                                                                                                                                                                                                                                                                                                                                  ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.y.^+w ].a+@@#@a+a+a+a+a+$@$@$@$@a+%@&@                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.^+w ].a+k+k+=@=@=@=@k+k+k+k+k+-@;@>@                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.^+w ].,@'@)@)@)@)@)@)@)@)@)@)@!@~@{@                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.]@^@/@'@(@_@:@:@:@:@:@:@:@:@:@<@[@                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.]@}@|@1@2@2@2@2@2@2@2@2@2@2@(@(@3@                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@{.]@4@)@5@6@6@6@6@6@6@6@6@6@6@7@8@9@                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@{.0@^@a@b@c@c@c@c@| | d@d@d@d@e@f@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@{.g@h@i@j@k@k@k@k@k@k@k@k@l@m@n@o@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.p@q@r@s@s@s@s@s@s@s@s@s@s@s@t@A.                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.u@v@w@x@x@x@x@x@x@x@x@x@x@y@z@A@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.B@C@*.D@D@D@D@D@D@D@D@D@n.E@F@G@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+*@H.H@u.W I@I@I@I@I@I@I@I@J@J@E@K@L@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.H.H@M@m -.-.-.-.-.-.-.-.-.-.N@O@P@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+*+,+I.H.H@M@m Q Q Q Q Q Q Q Q -.-.Q@R@P@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        8..+S@,+I.u H@M@m Q Q Q Q Q Q Q Q -.-.Q@R@P@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        T@U@P 1.V@r W@X@m Q Q Q Q Q Q Q Q -.-.Q@Y@P@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                        Z@`@ #.#+#@###$#)+Q Q Q Q Q Q Q Q -.-.%#&#Z@                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                                                                            *#=#-#;#            >#,#'#                                                    *#=#-#;#                    )#!#~#                                                                                                                                                                                                                              {#]#^#u+w+##/#!.!.Q Q Q Q Q Q Q -.-.(#_#                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ",
"                                                    )#:#:#:#:#:#<#                                          *#=#-#;#            >#,#'#            [#}#|#        1#2#<#                    *#=#-#;#                    )#!#~#                                                                                                                                                                                                                                3#4#u+u+v+v+5#m Q Q Q Q Q Q Q -.N 6#7#                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ",
"                                                    )#}#|#    )#:#<#                                                            >#,#'#            [#}#|#        1#2#<#                                                )#!#~#              [#}#|#                                                                                                                                                                                                            } 8#E+u+9#0#a#W Q Q Q Q Q Q Q -.Q@b#c#                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ",
"                                                    )#}#|#    >#,#d#                                                            >#,#'#            [#}#|#        1#2#<#                                                )#!#~#              [#}#|#                                                                                                                                                                                                              e#f#g#h#i#j#@.Q Q Q Q Q Q Q -.k#l#                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                    )#}#|#    >#,#d#      m#:#:#:#'#      )#-#n#,#:#:#'#    *#=#-#;#    [#:#:#}#o#,#'#            [#}#|#        1#2#<#      [#:#:#:#d#    *#=#-#;#    m#:#:#:#:#:#'#  )#!#p#,#:#:#'#  *#=#:#:#:#:#d#                                                                                                                                                                                                            q#r#u+v+.#s#@.Q Q Q Q Q Q -.k#t#                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                    )#}#|#    m#}#|#    m#'#    [#:#<#    )#:#}#|#  [#:#'#  *#=#-#;#  [#:#<#  1#2#:#'#            [#}#|#        1#2#<#    [#:#<#  1#2#'#  *#=#-#;#  m#!#~#  )#}#|#    )#:#!#~#  )#:#<#    [#}#|#                                                                                                                                                                                                                u#v#o+h#i#w#>.Q Q Q Q Q Q x#y#z#                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                    )#:#:#:#:#-#;#              >#,#d#    )#:#<#      m#-#;#*#=#-#;#*#=#d#      1#2#'#            [#:#:#:#:#:#:#:#:#<#  *#=#d#      )#!#~#*#=#-#;#>#,#'#    >#,#'#    )#}#|#    >#,#'#    [#}#|#                                                                                                                                                                                                                  A#B#h#C#S@>.Q Q Q Q Q Q D#E#                                                                                                                                                                                                                                                                                                                                                                                                                                                                              ",
"                                                    )#}#|#  )#:#<#              *#=#d#    )#!#~#      )#}#|#*#=#-#;#>#,#'#      >#,#'#            [#}#|#        1#2#<#  1#2#<#      [#}#|#*#=#-#;#>#,#'#    >#,#'#    )#!#~#    *#=#d#    [#}#|#                                                                                                                                                                                                                  F#G###n+V+H#!.Q Q Q Q Q (#I#                                                                                                                                                                                                                                                                                                                                                                                                                                                                              ",
"                                                    )#}#|#  *#=#!#~#    *#=#:#:#:#:#d#    )#!#~#      )#}#|#*#=#-#;#1#2#'#      >#,#'#            [#}#|#        1#2#<#  1#2#:#:#:#:#:#}#|#*#=#-#;#  m#!#~#  )#}#|#    )#!#~#    *#=#d#    [#}#|#                                                                                                                                                                                                                    J#B#K#D+L#M#Q Q Q Q N#O#P#                                                                                                                                                                                                                                                                                                                                                                                                                                                                              ",
"                                                    )#}#|#    [#:#<#  *#=#-#;#  *#=#d#    )#!#~#      )#!#~#*#=#-#;#>#,#'#      >#,#'#            [#}#|#        1#2#<#  1#2#<#            *#=#-#;#*#=#:#:#:#}#|#      )#!#~#    *#=#d#    [#}#|#                                                                                                                                                                                                                    c#Q#r#R#S#/+Q Q Q Q T#U#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                ",
"                                                    )#}#|#    >#,#d#  1#2#'#    *#=#d#    )#}#|#      m#-#;#*#=#-#;#*#=#d#      1#2#'#            [#}#|#        1#2#<#  >#,#'#            *#=#-#;#1#V#|#              )#!#~#    *#=#d#    [#}#|#                                                                                                                                                                                                                      W#X#d+,@k.!.Q Q Q Y#Z#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                ",
"                                                    )#}#|#      m#!#~#>#,#d#    m#:#d#    )#:#}#|#  [#:#<#  *#=#-#;#  )#:#<#  1#2#:#'#            [#}#|#        1#2#<#    )#:#<#    [#-#;#*#=#-#;#  m#:#:#:#:#:#<#    )#!#~#    *#=#d#    1#2#'#                                                                                                                                                                                                                        `# $9#.$@.Q Q +$T#@$                                                                                                                                                                                                                                                                                                                                                                                                                                                                                ",
"                                                    )#}#|#      [#:#'#  1#2#:#:#'#m#d#    )#!##$2#:#:#<#    *#=#-#;#    )#:#:#!#$$=#'#            [#}#|#        1#2#<#      [#:#:#:#-#;#  *#=#-#;#>#,#'#      )#}#|#  )#!#~#    *#=#d#      )#:#:#d#                                                                                                                                                                                                                    %$&$*$=$W Q Q -$L.P@                                                                                                                                                                                                                                                                                                                                                                                                                                                                                ",
"                                                                                          )#!#~#                                                                                                  )#!#~#      1#2#<#                                                                                                                                                                                                                                                      ;$>$,$#+Q Q Y#'$                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  ",
"                                                                                          )#!#~#                                                                                                  [#:#<#    *#=#!#~#                                                                                                                                                                                                                                                      )$!$q+s#x.Q Y#~$                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  ",
"                                                                                          )#!#~#                                                                                                    [#:#:#:#:#-#;#                                                                                                                                                                                                                                                          {$]$^$/$($@._$                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                            . :$<$)+[$}$                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |$1$N@2$3$                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                4$5$x.6$                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#                    7$a@8$Z@                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#                      9$0$                                                                                                                                                                                                                                                                                                >#,#'#                                                    *#=#-#;#                    )#!#~#                                                                                          ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#                      a$b$                                                                                                                                                                                                                                [#:#:#:#:#:#!#~#                                                >#,#'#            [#}#|#        1#2#<#                    *#=#-#;#                    )#!#~#                                                                                          ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#                                                          >#,#'#            [#}#|#        1#2#<#                                                )#!#~#              [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#                                                          >#,#'#            [#}#|#        1#2#<#                                                )#!#~#              [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#              [#:#:#:#d#        [#:#:#:#d#        [#:#:#}#o#,#'#            [#}#|#        1#2#<#      [#:#:#:#d#    *#=#-#;#    m#:#:#:#:#:#'#  )#!#p#,#:#:#'#  *#=#:#:#:#:#d#                                                                  ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#            [#:#<#  1#2#'#    [#:#<#  1#2#'#    [#:#<#  1#2#:#'#            [#}#|#        1#2#<#    [#:#<#  1#2#'#  *#=#-#;#  m#!#~#  )#}#|#    )#:#!#~#  )#:#<#    [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#          *#=#d#      )#!#~#*#=#d#      )#!#~#*#=#d#      1#2#'#            [#:#:#:#:#:#:#:#:#<#  *#=#d#      )#!#~#*#=#-#;#>#,#'#    >#,#'#    )#}#|#    >#,#'#    [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#:#:#:#:#-#;#1#2#<#      [#}#|#1#2#<#      [#}#|#>#,#'#      >#,#'#            [#}#|#        1#2#<#  1#2#<#      [#}#|#*#=#-#;#>#,#'#    >#,#'#    )#!#~#    *#=#d#    [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#          1#2#:#:#:#:#:#}#|#1#2#:#:#:#:#:#}#|#1#2#'#      >#,#'#            [#}#|#        1#2#<#  1#2#:#:#:#:#:#}#|#*#=#-#;#  m#!#~#  )#}#|#    )#!#~#    *#=#d#    [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#          1#2#<#            1#2#<#            >#,#'#      >#,#'#            [#}#|#        1#2#<#  1#2#<#            *#=#-#;#*#=#:#:#:#}#|#      )#!#~#    *#=#d#    [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#          >#,#'#            >#,#'#            *#=#d#      1#2#'#            [#}#|#        1#2#<#  >#,#'#            *#=#-#;#1#V#|#              )#!#~#    *#=#d#    [#}#|#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#            )#:#<#    [#-#;#  )#:#<#    [#-#;#  )#:#<#  1#2#:#'#            [#}#|#        1#2#<#    )#:#<#    [#-#;#*#=#-#;#  m#:#:#:#:#:#<#    )#!#~#    *#=#d#    1#2#'#                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      [#:#<#              [#:#:#:#-#;#      [#:#:#:#-#;#      )#:#:#!#$$=#'#            [#}#|#        1#2#<#      [#:#:#:#-#;#  *#=#-#;#>#,#'#      )#}#|#  )#!#~#    *#=#d#      )#:#:#d#                                                                  ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        )#!#~#      1#2#<#                                                                                                  ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        [#:#<#    *#=#!#~#                                                                                                  ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          [#:#:#:#:#-#;#                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#c$                                                              ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#c$                                                              ",
"                                                                                                                                    *#=#-#;#            *#=#-#;#                                                                                                                                                                                                                                                                                                                      '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#c$                                                              ",
"                                                    [#:#:#:#:#:#:#}#|#          [#:#:#:#:#:#'#                                      *#=#-#;#            *#=#-#;#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                              *#=#!#~#          [#}#|#    [#:#d#                                              [#}#|#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                              [#:#<#            [#}#|#      m#!#~#                                            [#}#|#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                            >#,#-#;#            [#}#|#      )#}#|#    1#2#:#:#:#<#      >#,#:#:#<#  *#=#-#d$=#:#:#:#:#d#*#=#-#;#    1#2#:#:#:#<#      )#-#n#,#:#:#'#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ",
"                                                            m#}#|#              [#}#|#      m#!#~#  [#:#'#    [#:#<#  *#=#d#  *#e$~#*#=#-#;#  [#}#|#    *#=#-#;#  [#:#'#    [#:#<#    )#:#!#~#  )#:#<#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                          1#2#d#                [#}#|#    )#:#'#  *#=#d#        m#-#;#>#,#<#        *#=#-#;#  [#}#|#    *#=#-#;#*#=#d#        m#-#;#  )#}#|#    >#,#'#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                        *#=#!#~#                [#:#:#:#:#}#|#    1#2#'#        )#}#|#*#=#:#<#      *#=#-#;#  [#}#|#    *#=#-#;#1#2#'#        )#}#|#  )#!#~#    *#=#d#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                        [#:#<#                  [#}#|#            1#2#<#        [#}#|#  *#=#:#:#<#  *#=#-#;#  [#}#|#    *#=#-#;#1#2#<#        [#}#|#  )#!#~#    *#=#d#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                      >#,#-#;#                  [#}#|#            1#2#'#        )#}#|#      *#=#}#|#*#=#-#;#  [#}#|#    *#=#-#;#1#2#'#        )#}#|#  )#!#~#    *#=#d#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                      )#}#|#                    [#}#|#            *#=#d#        m#-#;#        1#2#<#*#=#-#;#  [#}#|#    *#=#-#;#*#=#d#        m#-#;#  )#!#~#    *#=#d#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                    1#2#d#                      [#}#|#              )#:#<#    )#:#<#  [#d#    )#}#|#*#=#-#;#  1#2#'#    *#=#-#;#  )#:#<#    )#:#<#    )#!#~#    *#=#d#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                    )#:#:#:#:#:#:#:#'#          [#}#|#                [#:#:#:#}#|#      m#:#:#}#|#  *#=#-#;#    )#:#:#d#*#=#-#;#    [#:#:#:#}#|#      )#!#~#    *#=#d#                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                  Z@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@f$.                         . f$P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@P@{@                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  g$h$i$i$i$i$i$j$j$j$j$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$l$l$l$l$l$l$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$n$o$p$                    q$r$r$s$s$s$s$s$s$s$s$s$s$s$s$s$s$s$s$s$s$s$s$s$m$m$m$m$m$m$m$m$m$m$m$m$m$m$m$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$l$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$k$j$j$j$j$j$j$j$j$j$j$j$j$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$t$i$i$i$i$i$i$m$u$v$                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#        w$x$y$y$y$y$y$z$z$z$z$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$B$B$B$B$B$B$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$D$E$F$                    G$x$C$H$H$H$H$H$H$H$H$H$H$H$H$H$H$H$H$H$H$H$H$H$C$C$C$C$C$C$C$C$C$C$C$C$C$C$C$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$B$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$A$I$z$z$z$z$z$z$z$z$z$z$z$z$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$J$y$y$y$y$y$y$C$K$L$                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#        M$N$O$O$O$O$O$P$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$S$T$                U$V$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#        M$N$O$O$O$O$O$P$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$`$(+ %            .%s$+%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$P$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$@%#%            $%%%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$P$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$D$&%_$        *%=%A$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$P$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$%%-%        ;%>%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$X$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$,%'%q$    )%S$!%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$X$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$S$~%  {%]%N$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$^%/%(%_%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#        M$N$O$O$O$O$O$O$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$H$k$:%C$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#        M$N$O$O$O$O$O$O$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$C$C$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                '#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#:#'#        M$N$O$O$O$O$O$O$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                          )#!#~#                                                                                                                                                                  M$N$O$O$O$O$O$O$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                    [#:#:#:#:#:#:#}#|#          [#:#:#:#:#:#!#~#                                                          )#!#~#                                                                                                                                                                  M$N$O$O$O$O$O$O$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                              *#=#!#~#          [#:#<#      m#:#'#                                            [#}#|#      )#!#~#                                                                                                                                                                  M$N$O$O$O$O$O$O$P$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                              [#:#<#            [#:#<#        )#:#<#                                          [#}#|#      )#!#~#                                                                                                                                                                  M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                            >#,#-#;#            [#:#<#        *#=#-#;#    [#:#:#:#d#      )#-#n#,#:#:#'#  *#=#:#:#:#:#d#  )#!#p#,#:#:#'#                                                                                                                                                          M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                            m#}#|#              [#:#<#          m#!#~#  [#:#<#  1#2#'#    )#:#}#|#  [#:#'#    [#}#|#      )#:#!#~#  )#:#<#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                          1#2#d#                [#:#<#          )#}#|#*#=#d#      )#!#~#  )#:#<#      m#-#;#  [#}#|#      )#}#|#    >#,#'#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                        *#=#!#~#                [#:#<#          )#}#|#1#2#<#      [#}#|#  )#!#~#      )#}#|#  [#}#|#      )#!#~#    *#=#d#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                        [#:#<#                  [#:#<#          m#!#~#1#2#:#:#:#:#:#}#|#  )#!#~#      )#}#|#  [#}#|#      )#!#~#    *#=#d#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                      >#,#-#;#                  [#:#<#        *#=#d#  1#2#<#              )#!#~#      )#!#~#  [#}#|#      )#!#~#    *#=#d#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                      )#}#|#                    [#:#<#        )#:#<#  >#,#'#              )#}#|#      m#-#;#  [#}#|#      )#!#~#    *#=#d#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                    1#2#d#                      [#:#<#      )#:#'#      )#:#<#    [#-#;#  )#:#}#|#  [#:#<#    1#2#'#      )#!#~#    *#=#d#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                    )#:#:#:#:#:#:#:#'#          [#:#:#:#:#:#-#;#          [#:#:#:#-#;#    )#!##$2#:#:#<#        )#:#:#d#  )#!#~#    *#=#d#                                                                                                                                                        M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                          )#!#~#                                                                                                                                                                                                  M$N$O$O$O$O$O$O$P$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                          )#!#~#                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                          )#!#~#                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$P$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$O$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$X$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$O$<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$R$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$X$<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$X$<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$O$<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$[%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$K$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$O$<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$<%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$<%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$<%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$<%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$[%<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$}%}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  M$N$O$O$<%<%<%<%Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$R$R$R$R$R$R$R$}%W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$W$K$K$K$K$K$K$K$K$K$K$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$R$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$Q$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$P$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$O$O$O$O$O$O$K$Y$Z$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  |%1%+%+%2%2%2%2%`$3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%4%4%4%4%4%4%5%S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$S$6%6%6%6%6%6%6%6%6%6%4%4%4%4%4%4%4%4%4%4%4%4%4%4%4%4%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%7%7%7%7%7%7%7%7%7%7%7%7%7%7%7%7%7%7%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%8%+%+%+%+%+%+%6%9%L$                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                  0%~%a%a%b%b%b%b%b%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%d%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%b%a%a%a%a%a%a%c%e%f%                                                                                                                                                                                                    ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            "}
return f1
